@@ -3,13 +3,15 @@
 Should be used at a higher level, e.g. for constructing "subrepos"
 tasks.
 """
+
 from collections.abc import Sequence
 
+from cleez.colors import bold
 from invoke import Context
 
 
 def h1(msg: str):
-    print(msg)
+    print(bold(msg))
 
 
 def run_in_subrepos(c: Context, cmd: str, sub_repos: Sequence[str] = ()):
